"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateAbility = exports.schemaBaseIdToken = exports.AuthTokenType = void 0;
const ability_1 = require("@casl/ability");
const type_1 = require("../type");
var AuthTokenType;
(function (AuthTokenType) {
    AuthTokenType["Bearer"] = "Bearer";
    AuthTokenType["Basic"] = "Basic";
})(AuthTokenType = exports.AuthTokenType || (exports.AuthTokenType = {}));
exports.schemaBaseIdToken = {
    userId: type_1._id.required(),
    userLogin: type_1._userLogin.required(),
    localeCode: type_1._localeCode.required(),
    orgId: type_1._id.allow(null),
    appDomain: type_1._appDomain.allow(null),
    productId: type_1._id.allow(null)
};
function generateAbility(rules, vars) {
    const { can, cannot, build } = new ability_1.AbilityBuilder(ability_1.Ability);
    if (0 < rules?.length) {
        for (const rule of rules) {
            const parsedCondition = renderCondition(rule.conditions, vars);
            if (rule.inverted) {
                cannot(rule.action, rule.subject, rule.fields, parsedCondition);
            }
            else {
                can(rule.action, rule.subject, rule.fields, parsedCondition);
            }
        }
    }
    return build();
}
exports.generateAbility = generateAbility;
function renderCondition(conditions, vars) {
    if (conditions) {
        for (const key of Object.keys(conditions)) {
            // Support max 10 variables
            for (let i = 0; 10 > i; i++) {
                const renderedValue = renderValue(conditions[key], vars);
                if (undefined !== renderedValue) {
                    conditions[key] = renderedValue;
                    continue;
                }
                break;
            }
        }
    }
    return conditions;
}
function renderValue(value, vars) {
    if ('string' === typeof value) {
        const key = getKey(value);
        if (key) {
            const renderedValue = getValueByPath(vars, key);
            if ('string' === typeof renderedValue) {
                return value.replaceAll(`\${${key}}`, renderedValue);
            }
            else if ('number' === typeof renderedValue) {
                // Dont overwrite the whole value, it might have other values
                if (`\${${key}}` !== value) {
                    return value.replaceAll(`\${${key}}`, `${value}`);
                }
                return value;
            }
        }
    }
}
function getKey(value) {
    const start = value.indexOf('${');
    if (0 <= start) {
        const end = value.indexOf('}', start + 2);
        if (start < end) {
            return value.slice(start + 2, end);
        }
    }
}
function getValueByPath(obj, path) {
    const paths = path.split('.');
    let value = obj;
    for (const key of paths) {
        value = value?.[key];
        if (undefined === value) {
            break;
        }
    }
    if ('object' !== typeof value) {
        return value;
    }
}
//# sourceMappingURL=auth-type.js.map