"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DomainEventCodec = void 0;
const cm_schema_event_1 = require("cm-schema-event");
const domain_schema_1 = require("./domain-schema");
const domain_event_cipher_1 = require("./domain-event-cipher");
class DomainEventCodec {
    constructor(cipher) {
        this.cipher = cipher;
        // Load schema from the central schema registry
        this.schemaMessage = new domain_schema_1.DomainSchema(cm_schema_event_1.Schema.DomainEventMessage);
    }
    async encode(message) {
        const encodedMessage = await this.schemaMessage.encode(message);
        if (this.cipher) {
            return this.cipher.encrypt(encodedMessage);
        }
        return domain_event_cipher_1.DomainEventCipher.isEnabled ? domain_event_cipher_1.DomainEventCipher.instance.encrypt(encodedMessage) : encodedMessage;
    }
    async decode(encodedBuffer) {
        const encodedMessage = this.cipher ? await this.cipher.decrypt(encodedBuffer) : domain_event_cipher_1.DomainEventCipher.isEnabled ? await domain_event_cipher_1.DomainEventCipher.instance.decrypt(encodedBuffer) : encodedBuffer;
        return this.schemaMessage.decode(encodedMessage);
    }
}
exports.DomainEventCodec = DomainEventCodec;
//# sourceMappingURL=domain-event-codec.js.map