import { ContextAwareError } from 'cm-libs-context-aware-error';
import { EachMessagePayload } from 'cm-libs-kafka';
import { DomainEventMessage } from './domain-event';
import { DomainEventCipher } from './domain-event-cipher';
export declare function initDomainEventConsumer<T, M>(topic: string, appendOrdinalIndex?: boolean, cipher?: DomainEventCipher): DomainEventConsumer<T, M>;
export declare function extractOrdinalIndex(hostname: string): string;
export declare type DomainEventHandler<T, M> = (message: DomainEventMessage<T, M>, payload: EachMessagePayload) => Promise<void>;
export declare type ExceptionHandler<T, M> = (error: Error | ContextAwareError, message: DomainEventMessage<T, M>, payload: EachMessagePayload) => Promise<void>;
export declare class DomainEventConsumer<T, M> {
    private config;
    readonly groupId: string;
    readonly topic: string;
    readonly heartbeatThreshold: number;
    private _consumer;
    private domainEvent;
    constructor(config: string, groupId: string, topic: string, heartbeatThreshold?: number, cipher?: DomainEventCipher);
    term(): Promise<void>;
    subscribe(handler: DomainEventHandler<T, M>, exceptionHandler?: ExceptionHandler<T, M>): Promise<void>;
    unsubscribe(): Promise<void>;
    getOffset(partition?: number): Promise<import("kafkajs").FetchOffsetsPartition[]>;
    get pulseTimestamp(): number;
    get consumer(): import("kafkajs").Consumer;
    get ready(): boolean;
}
