"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.authBearerTokenMiddleware = void 0;
const joi_1 = __importDefault(require("joi"));
const cm_libs_context_aware_error_1 = require("cm-libs-context-aware-error");
const type_1 = require("../type");
const auth_1 = require("../auth");
const http_auth_1 = require("./http-auth");
function authBearerTokenMiddleware(req, res, next) {
    const token = req.get('authorization');
    if (token && token.startsWith('Bearer ')) {
        const ability = (0, auth_1.generateAbility)();
        const authToken = (0, http_auth_1.getAuthToken)(req) || { type: null, info: { token: null, ability } };
        authToken.type = auth_1.AuthTokenType.Bearer;
        authToken.info.token = token;
        authToken.info.ability = ability;
        const orgId = req.get('x-org-id');
        if (undefined !== orgId) {
            const appDomain = req.get('x-app-domain');
            const productId = req.get('x-product-id');
            if (undefined !== appDomain && undefined !== productId) {
                const { error, value } = joi_1.default.object()
                    .keys({
                    orgId: type_1._idString.required(),
                    appDomain: type_1._appDomain.required(),
                    productId: type_1._idString.required()
                })
                    .validate({ orgId, appDomain, productId });
                if (error) {
                    (0, cm_libs_context_aware_error_1.throwFromError)(error, cm_libs_context_aware_error_1.errors.INVALID_REQUEST, {
                        function: 'authBearerTokenMiddleware',
                        details: error.details,
                        text: { input: error.details?.[0]?.context?.peers || error.details?.[0]?.context?.key }
                    });
                }
                authToken.info.authMetadata = {
                    bearer: {
                        orgId: value.orgId,
                        appDomain: value.appDomain,
                        productId: value.productId
                    }
                };
            }
        }
        (0, http_auth_1.setAuthToken)(req, authToken);
    }
    return next();
}
exports.authBearerTokenMiddleware = authBearerTokenMiddleware;
//# sourceMappingURL=http-auth-bearer.js.map