import Joi from 'joi';
import { AccessInfo } from '../auth';
import { BaseModelSchemas, BaseModelQueryHandler, BaseModelMiddleware } from './model-middleware';
export declare const gqlSchemaSortOrder: import("graphql").DocumentNode;
export declare const gqlSchemaQueryMode: import("graphql").DocumentNode;
export declare const gqlSchemaDateFilter: import("graphql").DocumentNode;
export declare const gqlSchemaStringFilter: import("graphql").DocumentNode;
export declare const gqlSchemaIntFilter: import("graphql").DocumentNode;
export declare type BaseModelBrowseArgs = {
    include?: any;
    pagination?: BaseModelBrowsePagination;
    select?: any;
    where?: any;
    orderBy?: any;
    distinct?: any;
    take?: number;
    skip?: number;
    options?: BaseModelBrowseOptions;
};
export interface BaseModelBrowsePagination {
    page?: number;
    pageSize?: number;
}
export declare const _page: Joi.NumberSchema;
export declare const _pageSize: Joi.NumberSchema;
export declare const _pagination: Joi.ObjectSchema<BaseModelBrowsePagination>;
export declare const gqlSchemaBrowsePagination: import("graphql").DocumentNode;
export declare type BaseModelBrowseOptions = {
    speedMode?: boolean;
};
export declare const _browseOptions: Joi.ObjectSchema<BaseModelBrowseOptions>;
export declare const gqlSchemaBrowseOptions: import("graphql").DocumentNode;
export declare type BaseModelBrowseReturn<T> = {
    items: T[];
    properties: BaseModelBrowsePagination & {
        count?: number;
    };
};
export declare const gqlSchemaBrowsePropertiesOutput: import("graphql").DocumentNode;
export declare class BaseModel<T, PrismaClient, Model, BrowseArgs extends BaseModelBrowseArgs> {
    readonly schemas: BaseModelSchemas;
    readonly model: Model;
    private middleware;
    constructor(middleware: BaseModelMiddleware<PrismaClient>, name: string, schemas?: BaseModelSchemas);
    run<T>(accessInfo: AccessInfo, promise: BaseModelQueryHandler<T>): Promise<T>;
    browse(params?: BrowseArgs): Promise<BaseModelBrowseReturn<T>>;
    get client(): PrismaClient;
}
